@@ -24,7 +24,7 @@ def color(c):
 def beep(f):
     winsound.Beep(frequency=f,duration=1000 )
 
-def play(fn)
+def play(fn):
     winsound.PlaySound(fn, winsound.SND_FILENAME)
         
 c=b'aHR0cHM6Ly9maW5hbmNlLm5hdmVyLmNvbS8vbWFya2\
